//LabPlot : PruneListDialog.h

#ifndef PRUNELISTDIALOG_H
#define PRUNELISTDIALOG_H

#include "ListDialog.h"

class PruneListDialog : public ListDialog
{
	Q_OBJECT
public:
	PruneListDialog(MainWin *mw, const char *name);
public slots:
	void setNumber(int n) { nle->setText(QString::number(n)); }	//!< set number of points to prune
private:
	KLineEdit *nle;
private slots:
	int apply_clicked();
};

#endif // PRUNELISTDIALOG_H
